import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class MakeWithTheFunny(BasicComicModule):
    latestUrl = 'http://www.mwtfunny.com/'
    imageUrl = 'http://www.mwtfunny.com/index.php?ComicID=%s'
    imageSearch = re.compile(r'<img src="(.+?strips/\d{4}-\d{2}-\d{2}\..+?)">')
    prevSearch = re.compile(r'<area shape="rect" coords="[^"]+" href="(index\.php\?ComicID=\d+)" alt="Previous comic">')
    help = 'Index format: n (unpadded)'
